# vim: set sw=4 ts=4 et nu:
#
# spec file for package freeseer
#
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

Name:           freeseer
Version:        2.5.3
Release:        1.15
License:        GPL-3.0
Summary:        Video Capture Utility
Url:            https://github.com/fosslc/freeseer/wiki/
Group:          Productivity/Publishing/Presentation
Source0:        http://cloud.github.com/downloads/fosslc/freeseer/freeseer-2.5.3.tar.gz
# Icons for desktop entries
Source1:        %{name}.png
Source99:       freeseer-rpmlintrc
# PATCH-FIX-UPSTREAM freeseer-add-desktop-file.patch malcolmlewis@opensuse.org -- Add missing desktop file and icon https://github.com/Freeseer/freeseer/issues/165
Patch0:         freeseer-add-desktop-file.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  python-devel
%if 0%{?suse_version} < 1210
BuildRequires:  python-setuptools
%else
BuildRequires:  python-distribute
%endif
BuildRequires:  python-qt4
BuildRequires:  python-qt4-devel
BuildRequires:  update-desktop-files
Requires:       python-feedparser
Requires:       python-qt4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} < 1140
Requires:       python-gobject2
%else
Requires:       python-gobject
%endif
# not actually needed but to make the build fail if it's not
# available in the repository (yes, we want that):
BuildRequires:  python-feedparser
Requires:       python-gstreamer-0_10
Requires:       python-sip-devel
%if 0%{?suse_version} < 1140
BuildRequires:  python-gobject2
%else
BuildRequires:  python-gobject
%endif
BuildRequires:  python-gstreamer-0_10
BuildRequires:  python-sip-devel
%if 0%{?suse_version}
%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%description
Freeseer a video capture utility capable of capturing presentations or demos.
It can capture USB, firewire, local desktop, and more. It captures video and
audio and mixes them together to produce a video, thus enabling you to capture
great presentations, demos, or training material easily.

%prep
%setup -q
%patch0 -p1
cp %{S:1} data/
find src/freeseer/ -type f -name '*.py' | while read f; do
    perl -n -i -e 'print unless $.==1 && m/^#!/' "$f"
done

%build
python setup.py build

%install
python setup.py install -O1 --skip-build --prefix=%{_prefix} --root=%{buildroot}
%suse_update_desktop_file %{name}
%fdupes %{buildroot}

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc *.txt
%{_bindir}/%{name}-*
%{python_sitelib}/%{name}/
%{python_sitelib}/%{name}-%{version}-py%{py_ver}.egg-info
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/*.png

%changelog
* Fri Feb 10 2012 malcolmlewis@opensuse.org
- Add freeseer-add-desktop-file.patch: Add missing desktop file and
  icon https://github.com/Freeseer/freeseer/issues/165.
* Fri Jan 27 2012 malcolmlewis@opensuse.org
- Updated to 2.5.3:
  + Added delay recording option.
  + Added validation to some fields in the config tool.
  + Fixes for streaming to icecast. Seems to be working well now.
  + RPM Packaging can now be generated, installed.
  + Windows installer can now be generated, installed.
- Updates from 2.5.0:
  + Added streaming support to icecast!!
  + We now support Windows!
  + Setup functionality updated to enable packaging for
    Linux/Windows.
  + Windows now remember their position.
  + Config tool is now a separate tool from the recording tool.
  + Talk editor is now a separate tool from the recording tool.
  + Talks are now sorted by time.
  + A shortened version of Event, Room, Speaker, Title is now used
    to calculate filenames.
  + Test button is disabled during recording.
  + Talk/Event/Room drop downs are disabled during recording.
  + Fixed quite a few indendation problems.
  + Added support for cmake in addition to make to compile GUI
    screens.
  + Removed hotkey code and dependency on libqxt.
- Updates from 2.0.1:
  + Encode unicode characters to ascii since gstreamer doesn't
    support unicode.
  + Disable the talk/event/room drop down lists when recording.
  + Selecting the event now filters the room choices for that
    event.
  + We now check if the videos directory is writable beforehand.
  + Fixed SQLite cursor error seen on Fedora 14.
  + Refer to libQxt from path where it is installed during source
    build.
- Spec file clean up via spec-cleaner.
- Add desktop entry and icon for recorder.
- Drop freeseer.desktop source file.
- Spec file copyright added.
- Add python setup tools to BuildRequires.
- Update spec file License field from GPLv3 to GPL-3.0 to conform
  with spdx.org identifier.
* Sat Apr  2 2011 pascal.bleser@opensuse.org
- initial version (2.0.0)
